# SPDX-License-Identifier: BSD-2-Clause

# Copyright (c) 2025 Phil Thompson <phil@riverbankcomputing.com>


from ..abstract_project import AbstractProject
from ..exceptions import handle_exception


def main():
    """ Build an sdist for the project from the command line. """

    try:
        project = AbstractProject.bootstrap('sdist',
                "Build an sdist for the project.")
        sdist_file = project.build_sdist('.')
        project.progress(f"{sdist_file} has been built.")
    except Exception as e:
        handle_exception(e)

    return 0


if __name__ == '__main__':
    import sys

    sys.exit(main())



# SPDX-License-Identifier: BSD-2-Clause

# Copyright (c) 2024 Phil Thompson <phil@riverbankcomputing.com>


try:
    import tomllib
except ImportError:
    import tomli as tomllib


def toml_load(toml_file):
    """ Return a dict containing the decoded contents of a TOML file. """

    with open(toml_file, 'rb') as f:
        return tomllib.load(f)


def toml_loads(toml_str):
    """ Return a dict containing the decoded contents of a TOML string. """

    return tomllib.loads(toml_str)
